# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'local_repositories.ui'
##
## Created by: Qt User Interface Compiler version 6.3.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QDate, QDateTime, QLocale,
    QMetaObject, QObject, QPoint, QRect,
    QSize, QTime, QUrl, Qt)
from PySide6.QtGui import (QBrush, QColor, QConicalGradient, QCursor,
    QFont, QFontDatabase, QGradient, QIcon,
    QImage, QKeySequence, QLinearGradient, QPainter,
    QPalette, QPixmap, QRadialGradient, QTransform)
from PySide6.QtWidgets import (QApplication, QHBoxLayout, QLineEdit, QListWidget,
    QListWidgetItem, QPushButton, QSizePolicy, QVBoxLayout,
    QWidget)

class Ui_LocalRepositories(object):
    def setupUi(self, LocalRepositories):
        if not LocalRepositories.objectName():
            LocalRepositories.setObjectName(u"LocalRepositories")
        LocalRepositories.resize(556, 357)
        self.verticalLayout = QVBoxLayout(LocalRepositories)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.horizontalLayout_2 = QHBoxLayout()
        self.horizontalLayout_2.setObjectName(u"horizontalLayout_2")
        self.horizontalLayout_2.setContentsMargins(-1, -1, -1, 0)
        self.lineEdit = QLineEdit(LocalRepositories)
        self.lineEdit.setObjectName(u"lineEdit")

        self.horizontalLayout_2.addWidget(self.lineEdit)

        self.loadingButton = QPushButton(LocalRepositories)
        self.loadingButton.setObjectName(u"loadingButton")
        sizePolicy = QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.loadingButton.sizePolicy().hasHeightForWidth())
        self.loadingButton.setSizePolicy(sizePolicy)

        self.horizontalLayout_2.addWidget(self.loadingButton)


        self.verticalLayout.addLayout(self.horizontalLayout_2)

        self.listWidget = QListWidget(LocalRepositories)
        self.listWidget.setObjectName(u"listWidget")

        self.verticalLayout.addWidget(self.listWidget)

        self.horizontalLayout = QHBoxLayout()
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.horizontalLayout.setContentsMargins(-1, -1, -1, 0)
        self.lineEdit_2 = QLineEdit(LocalRepositories)
        self.lineEdit_2.setObjectName(u"lineEdit_2")

        self.horizontalLayout.addWidget(self.lineEdit_2)

        self.searchPathButton = QPushButton(LocalRepositories)
        self.searchPathButton.setObjectName(u"searchPathButton")

        self.horizontalLayout.addWidget(self.searchPathButton)


        self.verticalLayout.addLayout(self.horizontalLayout)

        self.searchButton = QPushButton(LocalRepositories)
        self.searchButton.setObjectName(u"searchButton")
        sizePolicy1 = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Fixed)
        sizePolicy1.setHorizontalStretch(0)
        sizePolicy1.setVerticalStretch(0)
        sizePolicy1.setHeightForWidth(self.searchButton.sizePolicy().hasHeightForWidth())
        self.searchButton.setSizePolicy(sizePolicy1)

        self.verticalLayout.addWidget(self.searchButton)


        self.retranslateUi(LocalRepositories)

        QMetaObject.connectSlotsByName(LocalRepositories)
    # setupUi

    def retranslateUi(self, LocalRepositories):
        LocalRepositories.setWindowTitle(QCoreApplication.translate("LocalRepositories", u"Form", None))
        self.lineEdit.setPlaceholderText(QCoreApplication.translate("LocalRepositories", u"Find a repository...", None))
        self.loadingButton.setText("")
        self.searchPathButton.setText(QCoreApplication.translate("LocalRepositories", u"Select directory", None))
        self.searchButton.setText(QCoreApplication.translate("LocalRepositories", u"Search", None))
    # retranslateUi




from importlib.metadata import version

from PySide6.QtCore import QSize
from PySide6.QtGui import QPixmap
from PySide6.QtWidgets import QMainWindow
from ui import Ui_GitHubManagerAbout
from utils import LOGO


class About(QMainWindow):
    def __init__(self):
        super(About, self).__init__()

        self.ui = Ui_GitHubManagerAbout()
        self.ui.setupUi(self)

        self.config_ui()

    def config_ui(self):
        self.ui.ghmImageLabel.setPixmap(QPixmap(LOGO).scaled(QSize(120, 120)))
        self.ui.versionLabel.setText(version("pygithubmanager"))



from PySide6.QtWidgets import QListWidgetItem


class RepositoriesListWidgetItem(QListWidgetItem):
    def __init__(self, repo):
        """
        RepositoriesListWidgetItem class constructor.

        Parameters
        ----------
        repo
        """
        super().__init__()
        self.repo = repo



# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'create_repository.ui'
##
## Created by: Qt User Interface Compiler version 6.3.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QMetaObject, Qt)
from PySide6.QtGui import (QFont)
from PySide6.QtWidgets import (QCheckBox, QFormLayout, QHBoxLayout,
                               QLabel, QLineEdit, QPushButton, QSizePolicy,
                               QVBoxLayout)

from widgets.AutocompletableComboBox import Autocomplete
from widgets.IconLabel import IconLabel


class Ui_CreateRepo(object):
    def setupUi(self, CreateRepo):
        if not CreateRepo.objectName():
            CreateRepo.setObjectName(u"CreateRepo")
        CreateRepo.resize(498, 398)
        self.verticalLayout = QVBoxLayout(CreateRepo)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.horizontalLayout = QHBoxLayout()
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.label = QLabel(CreateRepo)
        self.label.setObjectName(u"label")
        sizePolicy = QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy)
        font = QFont()
        font.setPointSize(16)
        font.setBold(True)
        self.label.setFont(font)
        self.label.setAlignment(Qt.AlignCenter)

        self.horizontalLayout.addWidget(self.label)

        self.verticalLayout.addLayout(self.horizontalLayout)

        self.warningLabel = IconLabel(CreateRepo)
        self.warningLabel.setObjectName(u"warningLabel")
        sizePolicy.setHeightForWidth(self.warningLabel.sizePolicy().hasHeightForWidth())
        self.warningLabel.setSizePolicy(sizePolicy)

        self.verticalLayout.addWidget(self.warningLabel)

        self.formLayout = QFormLayout()
        self.formLayout.setObjectName(u"formLayout")
        self.nameLabel = QLabel(CreateRepo)
        self.nameLabel.setObjectName(u"nameLabel")

        self.formLayout.setWidget(0, QFormLayout.LabelRole, self.nameLabel)

        self.nameLineEdit = QLineEdit(CreateRepo)
        self.nameLineEdit.setObjectName(u"nameLineEdit")

        self.formLayout.setWidget(0, QFormLayout.FieldRole, self.nameLineEdit)

        self.descriptionLabel = QLabel(CreateRepo)
        self.descriptionLabel.setObjectName(u"descriptionLabel")

        self.formLayout.setWidget(1, QFormLayout.LabelRole, self.descriptionLabel)

        self.descriptionLineEdit = QLineEdit(CreateRepo)
        self.descriptionLineEdit.setObjectName(u"descriptionLineEdit")

        self.formLayout.setWidget(1, QFormLayout.FieldRole, self.descriptionLineEdit)

        self.homepageLabel = QLabel(CreateRepo)
        self.homepageLabel.setObjectName(u"homepageLabel")

        self.formLayout.setWidget(2, QFormLayout.LabelRole, self.homepageLabel)

        self.homepageLineEdit = QLineEdit(CreateRepo)
        self.homepageLineEdit.setObjectName(u"homepageLineEdit")

        self.formLayout.setWidget(2, QFormLayout.FieldRole, self.homepageLineEdit)

        self.privateLabel = QLabel(CreateRepo)
        self.privateLabel.setObjectName(u"privateLabel")

        self.formLayout.setWidget(3, QFormLayout.LabelRole, self.privateLabel)

        self.privateCheckBox = QCheckBox(CreateRepo)
        self.privateCheckBox.setObjectName(u"privateCheckBox")

        self.formLayout.setWidget(3, QFormLayout.FieldRole, self.privateCheckBox)

        self.hasIssuesLabel = QLabel(CreateRepo)
        self.hasIssuesLabel.setObjectName(u"hasIssuesLabel")

        self.formLayout.setWidget(4, QFormLayout.LabelRole, self.hasIssuesLabel)

        self.hasIssuesCheckBox = QCheckBox(CreateRepo)
        self.hasIssuesCheckBox.setObjectName(u"hasIssuesCheckBox")

        self.formLayout.setWidget(4, QFormLayout.FieldRole, self.hasIssuesCheckBox)

        self.hasWikiLabel = QLabel(CreateRepo)
        self.hasWikiLabel.setObjectName(u"hasWikiLabel")

        self.formLayout.setWidget(5, QFormLayout.LabelRole, self.hasWikiLabel)

        self.hasWikiCheckBox = QCheckBox(CreateRepo)
        self.hasWikiCheckBox.setObjectName(u"hasWikiCheckBox")

        self.formLayout.setWidget(5, QFormLayout.FieldRole, self.hasWikiCheckBox)

        self.hasDownloadsLabel = QLabel(CreateRepo)
        self.hasDownloadsLabel.setObjectName(u"hasDownloadsLabel")

        self.formLayout.setWidget(6, QFormLayout.LabelRole, self.hasDownloadsLabel)

        self.hasDownloadsCheckBox = QCheckBox(CreateRepo)
        self.hasDownloadsCheckBox.setObjectName(u"hasDownloadsCheckBox")

        self.formLayout.setWidget(6, QFormLayout.FieldRole, self.hasDownloadsCheckBox)

        self.hasProjectsLabel = QLabel(CreateRepo)
        self.hasProjectsLabel.setObjectName(u"hasProjectsLabel")

        self.formLayout.setWidget(7, QFormLayout.LabelRole, self.hasProjectsLabel)

        self.hasProjectsCheckBox = QCheckBox(CreateRepo)
        self.hasProjectsCheckBox.setObjectName(u"hasProjectsCheckBox")

        self.formLayout.setWidget(7, QFormLayout.FieldRole, self.hasProjectsCheckBox)

        self.autoInitLabel = QLabel(CreateRepo)
        self.autoInitLabel.setObjectName(u"autoInitLabel")

        self.formLayout.setWidget(8, QFormLayout.LabelRole, self.autoInitLabel)

        self.autoInitCheckBox = QCheckBox(CreateRepo)
        self.autoInitCheckBox.setObjectName(u"autoInitCheckBox")

        self.formLayout.setWidget(8, QFormLayout.FieldRole, self.autoInitCheckBox)

        self.licenseTemplateLabel = QLabel(CreateRepo)
        self.licenseTemplateLabel.setObjectName(u"licenseTemplateLabel")

        self.formLayout.setWidget(9, QFormLayout.LabelRole, self.licenseTemplateLabel)

        self.licenseTemplateComboBox = Autocomplete(CreateRepo)
        self.licenseTemplateComboBox.setObjectName(u"licenseTemplateComboBox")

        self.formLayout.setWidget(9, QFormLayout.FieldRole, self.licenseTemplateComboBox)

        self.allowRebaseMergeLabel = QLabel(CreateRepo)
        self.allowRebaseMergeLabel.setObjectName(u"allowRebaseMergeLabel")

        self.formLayout.setWidget(10, QFormLayout.LabelRole, self.allowRebaseMergeLabel)

        self.allowRebaseMergeCheckBox = QCheckBox(CreateRepo)
        self.allowRebaseMergeCheckBox.setObjectName(u"allowRebaseMergeCheckBox")

        self.formLayout.setWidget(10, QFormLayout.FieldRole, self.allowRebaseMergeCheckBox)

        self.allowMergeCommitLabel = QLabel(CreateRepo)
        self.allowMergeCommitLabel.setObjectName(u"allowMergeCommitLabel")

        self.formLayout.setWidget(11, QFormLayout.LabelRole, self.allowMergeCommitLabel)

        self.allowMergeCommitCheckBox = QCheckBox(CreateRepo)
        self.allowMergeCommitCheckBox.setObjectName(u"allowMergeCommitCheckBox")

        self.formLayout.setWidget(11, QFormLayout.FieldRole, self.allowMergeCommitCheckBox)

        self.gitignoreTemplateLabel = QLabel(CreateRepo)
        self.gitignoreTemplateLabel.setObjectName(u"gitignoreTemplateLabel")

        self.formLayout.setWidget(12, QFormLayout.LabelRole, self.gitignoreTemplateLabel)

        self.gitignoreTemplateComboBox = Autocomplete(CreateRepo)
        self.gitignoreTemplateComboBox.setObjectName(u"gitignoreTemplateComboBox")

        self.formLayout.setWidget(12, QFormLayout.FieldRole, self.gitignoreTemplateComboBox)

        self.verticalLayout.addLayout(self.formLayout)

        self.horizontalLayout_2 = QHBoxLayout()
        self.horizontalLayout_2.setObjectName(u"horizontalLayout_2")
        self.createRepoButton = QPushButton(CreateRepo)
        self.createRepoButton.setObjectName(u"createRepoButton")

        self.horizontalLayout_2.addWidget(self.createRepoButton)

        self.cancelButton = QPushButton(CreateRepo)
        self.cancelButton.setObjectName(u"cancelButton")
        sizePolicy.setHeightForWidth(self.cancelButton.sizePolicy().hasHeightForWidth())
        self.cancelButton.setSizePolicy(sizePolicy)

        self.horizontalLayout_2.addWidget(self.cancelButton)

        self.verticalLayout.addLayout(self.horizontalLayout_2)

        self.retranslateUi(CreateRepo)

        QMetaObject.connectSlotsByName(CreateRepo)
    # setupUi

    def retranslateUi(self, CreateRepo):
        CreateRepo.setWindowTitle(QCoreApplication.translate("CreateRepo", u"New Repository", None))
        self.label.setText(QCoreApplication.translate("CreateRepo", u"Create new repository", None))
        self.nameLabel.setText(QCoreApplication.translate("CreateRepo", u"Name", None))
        self.descriptionLabel.setText(QCoreApplication.translate("CreateRepo", u"Description", None))
        self.homepageLabel.setText(QCoreApplication.translate("CreateRepo", u"Homepage", None))
        self.privateLabel.setText(QCoreApplication.translate("CreateRepo", u"Private", None))
        self.hasIssuesLabel.setText(QCoreApplication.translate("CreateRepo", u"Has issues", None))
        self.hasWikiLabel.setText(QCoreApplication.translate("CreateRepo", u"Has wiki", None))
        self.hasDownloadsLabel.setText(QCoreApplication.translate("CreateRepo", u"Has downloads", None))
        self.hasProjectsLabel.setText(QCoreApplication.translate("CreateRepo", u"Has projects", None))
        self.autoInitLabel.setText(QCoreApplication.translate("CreateRepo", u"Auto init", None))
        self.licenseTemplateLabel.setText(QCoreApplication.translate("CreateRepo", u"License template", None))
        self.allowRebaseMergeLabel.setText(QCoreApplication.translate("CreateRepo", u"Allow rebase merge", None))
        self.allowMergeCommitLabel.setText(QCoreApplication.translate("CreateRepo", u"Allow merge commit", None))
        self.gitignoreTemplateLabel.setText(QCoreApplication.translate("CreateRepo", u"Gitignore template", None))
        self.createRepoButton.setText(QCoreApplication.translate("CreateRepo", u"Create repository", None))
        self.cancelButton.setText(QCoreApplication.translate("CreateRepo", u"Cancel", None))
    # retranslateUi




def convert_float_to_decimal(f=0.0, precision=2):
    """
    Convert a float to string of decimal.
    precision: by default 2.
    If no arg provided, return "0.00".

    Parameters
    ----------
    f : float
        The float to be converted.
    precision : int
        The number of decimal places.

    Returns
    -------
    str
        The converted string.

    Examples
    --------
    >>> convert_float_to_decimal(1.23456789, 2)
    '1.23'
    >>> convert_float_to_decimal(1.23456789, 3)
    '1.235'
    >>> convert_float_to_decimal(1.23456789, 4)
    '1.2346'
    """
    return ("%." + str(precision) + "f") % f


def format_file_size(size, sizeIn, sizeOut, precision=0):
    """
    Convert file size to a string representing its value in B, KB, MB and GB.
    The convention is based on sizeIn as original unit and sizeOut
    as final unit.

    Parameters
    ----------
    size : float
        The size to be converted.
    sizeIn : str
        The original unit of the size.
    sizeOut : str
        The final unit of the size.
    precision : int
        The number of decimal places.

    Returns
    -------
    str
        The converted string.

    Examples
    --------
    >>> format_file_size(1.23456789, "B", "B", 0)
    '1.23 B'
    >>> format_file_size(1.23456789, "B", "KB", 0)
    '1.23 KB'
    >>> format_file_size(1.23456789, "B", "MB", 0)
    '1.23 MB'
    """
    assert sizeIn.upper() in {"B", "KB", "MB", "GB"}, "sizeIn type error"
    assert sizeOut.upper() in {"B", "KB", "MB", "GB"}, "sizeOut type error"
    if sizeIn == "B":
        if sizeOut == "KB":
            return convert_float_to_decimal((size / 1024.0), precision)
        elif sizeOut == "MB":
            return convert_float_to_decimal((size / 1024.0 ** 2), precision)
        elif sizeOut == "GB":
            return convert_float_to_decimal((size / 1024.0 ** 3), precision)
    elif sizeIn == "KB":
        if sizeOut == "B":
            return convert_float_to_decimal((size * 1024.0), precision)
        elif sizeOut == "MB":
            return convert_float_to_decimal((size / 1024.0), precision)
        elif sizeOut == "GB":
            return convert_float_to_decimal((size / 1024.0 ** 2), precision)
    elif sizeIn == "MB":
        if sizeOut == "B":
            return convert_float_to_decimal((size * 1024.0 ** 2), precision)
        elif sizeOut == "KB":
            return convert_float_to_decimal((size * 1024.0), precision)
        elif sizeOut == "GB":
            return convert_float_to_decimal((size / 1024.0), precision)
    elif sizeIn == "GB":
        if sizeOut == "B":
            return convert_float_to_decimal((size * 1024.0 ** 3), precision)
        elif sizeOut == "KB":
            return convert_float_to_decimal((size * 1024.0 ** 2), precision)
        elif sizeOut == "MB":
            return convert_float_to_decimal((size * 1024.0), precision)



# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'issue_template.ui'
##
## Created by: Qt User Interface Compiler version 6.3.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QMetaObject)
from PySide6.QtWidgets import (QHBoxLayout, QLabel, QSizePolicy,
                               QSpacerItem, QVBoxLayout)

from widgets.IconLabel import IconLabel


class Ui_IssueTemplate(object):
    def setupUi(self, IssueTemplate):
        if not IssueTemplate.objectName():
            IssueTemplate.setObjectName(u"IssueTemplate")
        IssueTemplate.resize(706, 87)
        self.verticalLayout = QVBoxLayout(IssueTemplate)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.horizontalLayout = QHBoxLayout()
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.statusNameWidget = IconLabel(IssueTemplate)
        self.statusNameWidget.setObjectName(u"statusNameWidget")
        sizePolicy = QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.statusNameWidget.sizePolicy().hasHeightForWidth())
        self.statusNameWidget.setSizePolicy(sizePolicy)

        self.horizontalLayout.addWidget(self.statusNameWidget)

        self.labelsLayout = QHBoxLayout()
        self.labelsLayout.setObjectName(u"labelsLayout")

        self.horizontalLayout.addLayout(self.labelsLayout)

        self.horizontalSpacer = QSpacerItem(40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.horizontalLayout.addItem(self.horizontalSpacer)

        self.commentsWidget = IconLabel(IssueTemplate)
        self.commentsWidget.setObjectName(u"commentsWidget")
        sizePolicy.setHeightForWidth(self.commentsWidget.sizePolicy().hasHeightForWidth())
        self.commentsWidget.setSizePolicy(sizePolicy)

        self.horizontalLayout.addWidget(self.commentsWidget)

        self.verticalLayout.addLayout(self.horizontalLayout)

        self.horizontalLayout_2 = QHBoxLayout()
        self.horizontalLayout_2.setObjectName(u"horizontalLayout_2")
        self.issueNumberLabel = QLabel(IssueTemplate)
        self.issueNumberLabel.setObjectName(u"issueNumberLabel")

        self.horizontalLayout_2.addWidget(self.issueNumberLabel)

        self.openedLabel = QLabel(IssueTemplate)
        self.openedLabel.setObjectName(u"openedLabel")

        self.horizontalLayout_2.addWidget(self.openedLabel)

        self.byLabel = QLabel(IssueTemplate)
        self.byLabel.setObjectName(u"byLabel")

        self.horizontalLayout_2.addWidget(self.byLabel)

        self.horizontalSpacer_2 = QSpacerItem(40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.horizontalLayout_2.addItem(self.horizontalSpacer_2)

        self.verticalLayout.addLayout(self.horizontalLayout_2)

        self.retranslateUi(IssueTemplate)

        QMetaObject.connectSlotsByName(IssueTemplate)

    # setupUi

    def retranslateUi(self, IssueTemplate):
        IssueTemplate.setWindowTitle(QCoreApplication.translate("IssueTemplate", u"Form", None))
        self.issueNumberLabel.setText(QCoreApplication.translate("IssueTemplate", u"#Issue", None))
        self.openedLabel.setText(QCoreApplication.translate("IssueTemplate", u"opened", None))
        self.byLabel.setText(QCoreApplication.translate("IssueTemplate", u"by", None))
    # retranslateUi



from PySide6.QtWebEngineCore import QWebEnginePage
from PySide6.QtWebEngineWidgets import QWebEngineView


class CustomWebEnginePage(QWebEnginePage):
    external_windows = []

    def acceptNavigationRequest(self, url, _type, isMainFrame):
        """
        Override the default navigation behavior.

        Parameters
        ----------
        url : str
            The URL to navigate to.
        _type : QWebEnginePage.NavigationType
            The type of navigation.
        isMainFrame : bool
            Whether the navigation is for the main frame.

        Returns
        -------
        bool
            Whether the navigation should be accepted.
        """
        if _type == QWebEnginePage.NavigationTypeLinkClicked:
            w = QWebEngineView()
            w.setUrl(url)
            w.show()

            self.external_windows.append(w)
            return False
        return super().acceptNavigationRequest(url, _type, isMainFrame)



from PySide6.QtWidgets import QListWidgetItem


class LocalRepositoryListWidgetItem(QListWidgetItem):
    def __init__(self, name, path):
        """
        QListWidgetItem to store the name and path of a local repository.
        Parameters
        ----------
        name : str
            Name of the repository.
        path : str
            Path of the repository.
        """
        super().__init__()
        self.name = name
        self.path = path



from PySide6.QtCore import QSize
from PySide6.QtWidgets import QWidget, QLabel
from github.Issue import Issue

from ui.widgets import Ui_IssueTemplate
from utils import time_formatter


class IssueTemplate(QWidget):
    def __init__(self, issue: Issue):
        """
        IssueTemplate is a widget that shows the information of an issue.

        Parameters
        ----------
        issue : Issue
            The issue to show.
        """
        super(IssueTemplate, self).__init__()
        self.ui = Ui_IssueTemplate()
        self.ui.setupUi(self)

        self.issue: Issue = issue

        self.fill()

    def fill(self):
        """
        Fills the widget with the information of the issue.
        """
        self.ui.statusNameWidget.setText(self.issue.title)
        self.ui.statusNameWidget.set_text_style(bold=True)
        self.ui.statusNameWidget.set_icon("msc.issues", "green", QSize(20, 20))

        self.ui.commentsWidget.setText(str(self.issue.comments))
        self.ui.commentsWidget.set_icon("fa5.comment-alt")

        for label in self.issue.labels:
            label_label = QLabel(label.name)
            label_label.setStyleSheet(
                "border: 1px solid #{color}; border-radius: 10px; padding: 1px;".format(color=label.color))
            self.ui.labelsLayout.addWidget(label_label)

        self.ui.issueNumberLabel.setText("#" + str(self.issue.number))
        self.ui.openedLabel.setText(time_formatter("opened", time2=self.issue.created_at))
        self.ui.byLabel.setText("by " + self.issue.user.login)



# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'mainwindow.ui'
##
## Created by: Qt User Interface Compiler version 6.3.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QMetaObject, QRect,
                            QSize, Qt)
from PySide6.QtGui import (QAction, QFont, QIcon)
from PySide6.QtWidgets import (QHBoxLayout, QLabel, QLayout,
                               QMenu, QMenuBar, QPushButton,
                               QSizePolicy, QSpacerItem, QStatusBar, QTabWidget,
                               QVBoxLayout, QWidget)

from widgets.IconLabel import IconLabel


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        if not MainWindow.objectName():
            MainWindow.setObjectName(u"MainWindow")
        MainWindow.resize(1020, 677)
        self.actionAbout = QAction(MainWindow)
        self.actionAbout.setObjectName(u"actionAbout")
        self.actionAyuda = QAction(MainWindow)
        self.actionAyuda.setObjectName(u"actionAyuda")
        self.actionExit = QAction(MainWindow)
        self.actionExit.setObjectName(u"actionExit")
        self.actionReload = QAction(MainWindow)
        self.actionReload.setObjectName(u"actionReload")
        self.centralwidget = QWidget(MainWindow)
        self.centralwidget.setObjectName(u"centralwidget")
        self.horizontalLayout = QHBoxLayout(self.centralwidget)
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.verticalLayout_2 = QVBoxLayout()
        self.verticalLayout_2.setObjectName(u"verticalLayout_2")
        self.verticalLayout_2.setSizeConstraint(QLayout.SetFixedSize)
        self.profileImageLabel = QLabel(self.centralwidget)
        self.profileImageLabel.setObjectName(u"profileImageLabel")
        sizePolicy = QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.profileImageLabel.sizePolicy().hasHeightForWidth())
        self.profileImageLabel.setSizePolicy(sizePolicy)

        self.verticalLayout_2.addWidget(self.profileImageLabel)

        self.nameLabel = QLabel(self.centralwidget)
        self.nameLabel.setObjectName(u"nameLabel")
        font = QFont()
        font.setPointSize(11)
        font.setBold(True)
        self.nameLabel.setFont(font)
        self.nameLabel.setAlignment(Qt.AlignLeading | Qt.AlignLeft | Qt.AlignVCenter)

        self.verticalLayout_2.addWidget(self.nameLabel)

        self.userNameLabel = QLabel(self.centralwidget)
        self.userNameLabel.setObjectName(u"userNameLabel")
        sizePolicy1 = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Fixed)
        sizePolicy1.setHorizontalStretch(0)
        sizePolicy1.setVerticalStretch(0)
        sizePolicy1.setHeightForWidth(self.userNameLabel.sizePolicy().hasHeightForWidth())
        self.userNameLabel.setSizePolicy(sizePolicy1)
        self.userNameLabel.setAlignment(Qt.AlignLeading | Qt.AlignLeft | Qt.AlignVCenter)

        self.verticalLayout_2.addWidget(self.userNameLabel)

        self.bioLabel = QLabel(self.centralwidget)
        self.bioLabel.setObjectName(u"bioLabel")
        sizePolicy1.setHeightForWidth(self.bioLabel.sizePolicy().hasHeightForWidth())
        self.bioLabel.setSizePolicy(sizePolicy1)
        self.bioLabel.setAlignment(Qt.AlignLeading | Qt.AlignLeft | Qt.AlignVCenter)

        self.verticalLayout_2.addWidget(self.bioLabel)

        self.editProfileButton = QPushButton(self.centralwidget)
        self.editProfileButton.setObjectName(u"editProfileButton")

        self.verticalLayout_2.addWidget(self.editProfileButton)

        self.companyWidget = IconLabel(self.centralwidget)
        self.companyWidget.setObjectName(u"companyWidget")
        sizePolicy2 = QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Preferred)
        sizePolicy2.setHorizontalStretch(0)
        sizePolicy2.setVerticalStretch(0)
        sizePolicy2.setHeightForWidth(self.companyWidget.sizePolicy().hasHeightForWidth())
        self.companyWidget.setSizePolicy(sizePolicy2)

        self.verticalLayout_2.addWidget(self.companyWidget)

        self.locationWidget = IconLabel(self.centralwidget)
        self.locationWidget.setObjectName(u"locationWidget")
        sizePolicy2.setHeightForWidth(self.locationWidget.sizePolicy().hasHeightForWidth())
        self.locationWidget.setSizePolicy(sizePolicy2)

        self.verticalLayout_2.addWidget(self.locationWidget)

        self.twitterWidget = IconLabel(self.centralwidget)
        self.twitterWidget.setObjectName(u"twitterWidget")
        sizePolicy2.setHeightForWidth(self.twitterWidget.sizePolicy().hasHeightForWidth())
        self.twitterWidget.setSizePolicy(sizePolicy2)

        self.verticalLayout_2.addWidget(self.twitterWidget)

        self.joinedWidget = IconLabel(self.centralwidget)
        self.joinedWidget.setObjectName(u"joinedWidget")
        sizePolicy2.setHeightForWidth(self.joinedWidget.sizePolicy().hasHeightForWidth())
        self.joinedWidget.setSizePolicy(sizePolicy2)

        self.verticalLayout_2.addWidget(self.joinedWidget)

        self.verticalSpacer = QSpacerItem(20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding)

        self.verticalLayout_2.addItem(self.verticalSpacer)

        self.infoButton = QPushButton(self.centralwidget)
        self.infoButton.setObjectName(u"infoButton")
        sizePolicy.setHeightForWidth(self.infoButton.sizePolicy().hasHeightForWidth())
        self.infoButton.setSizePolicy(sizePolicy)

        self.verticalLayout_2.addWidget(self.infoButton)


        self.horizontalLayout.addLayout(self.verticalLayout_2)

        self.verticalLayout = QVBoxLayout()
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.mainTabWidget = QTabWidget(self.centralwidget)
        self.mainTabWidget.setObjectName(u"mainTabWidget")
        self.mainTabWidget.setTabPosition(QTabWidget.North)
        self.mainTabWidget.setTabShape(QTabWidget.Rounded)
        self.mainTabWidget.setIconSize(QSize(16, 16))
        self.mainTabWidget.setElideMode(Qt.ElideMiddle)
        self.mainTabWidget.setDocumentMode(False)
        self.mainTabWidget.setTabsClosable(False)
        self.mainTabWidget.setMovable(False)
        self.overviewTab = QWidget()
        self.overviewTab.setObjectName(u"overviewTab")
        icon = QIcon()
        icon.addFile(u"../resources/icons/dark open book.png", QSize(), QIcon.Normal, QIcon.Off)
        self.mainTabWidget.addTab(self.overviewTab, icon, "")
        self.repositoriesTab = QWidget()
        self.repositoriesTab.setObjectName(u"repositoriesTab")
        icon1 = QIcon()
        icon1.addFile(u"../resources/icons/dark repo.png", QSize(), QIcon.Normal, QIcon.Off)
        self.mainTabWidget.addTab(self.repositoriesTab, icon1, "")
        self.localTab = QWidget()
        self.localTab.setObjectName(u"localTab")
        icon2 = QIcon()
        icon2.addFile(u"../resources/icons/dark star.png", QSize(), QIcon.Normal, QIcon.Off)
        self.mainTabWidget.addTab(self.localTab, icon2, "")

        self.verticalLayout.addWidget(self.mainTabWidget)


        self.horizontalLayout.addLayout(self.verticalLayout)

        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QMenuBar(MainWindow)
        self.menubar.setObjectName(u"menubar")
        self.menubar.setGeometry(QRect(0, 0, 1020, 22))
        self.menuHelp = QMenu(self.menubar)
        self.menuHelp.setObjectName(u"menuHelp")
        self.menuMenu = QMenu(self.menubar)
        self.menuMenu.setObjectName(u"menuMenu")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QStatusBar(MainWindow)
        self.statusbar.setObjectName(u"statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.menubar.addAction(self.menuMenu.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())
        self.menuHelp.addAction(self.actionAyuda)
        self.menuHelp.addSeparator()
        self.menuHelp.addAction(self.actionAbout)
        self.menuMenu.addAction(self.actionReload)
        self.menuMenu.addSeparator()
        self.menuMenu.addAction(self.actionExit)

        self.retranslateUi(MainWindow)

        self.mainTabWidget.setCurrentIndex(0)

        QMetaObject.connectSlotsByName(MainWindow)
    # setupUi

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QCoreApplication.translate("MainWindow", u"GitHub Manager", None))
        self.actionAbout.setText(QCoreApplication.translate("MainWindow", u"Acerca de", None))
        self.actionAyuda.setText(QCoreApplication.translate("MainWindow", u"Ayuda de GitHub Manager", None))
        self.actionExit.setText(QCoreApplication.translate("MainWindow", u"Exit", None))
        self.actionReload.setText(QCoreApplication.translate("MainWindow", u"Reload", None))
        # if QT_CONFIG(shortcut)
        self.actionReload.setShortcut(QCoreApplication.translate("MainWindow", u"Ctrl+R", None))
        # endif // QT_CONFIG(shortcut)
        self.profileImageLabel.setText("")
        self.nameLabel.setText(QCoreApplication.translate("MainWindow", u"name", None))
        self.userNameLabel.setText(QCoreApplication.translate("MainWindow", u"username", None))
        self.bioLabel.setText(QCoreApplication.translate("MainWindow", u"bio", None))
        self.editProfileButton.setText(QCoreApplication.translate("MainWindow", u"Edit profile", None))
        self.infoButton.setText("")
        self.mainTabWidget.setTabText(self.mainTabWidget.indexOf(self.overviewTab),
                                      QCoreApplication.translate("MainWindow", u"Overview", None))
        self.mainTabWidget.setTabText(self.mainTabWidget.indexOf(self.repositoriesTab),
                                      QCoreApplication.translate("MainWindow", u"Repositories", None))
        self.mainTabWidget.setTabText(self.mainTabWidget.indexOf(self.localTab),
                                      QCoreApplication.translate("MainWindow", u"Local", None))
        self.menuHelp.setTitle(QCoreApplication.translate("MainWindow", u"Help", None))
        self.menuMenu.setTitle(QCoreApplication.translate("MainWindow", u"Menu", None))
    # retranslateUi




# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'file_template.ui'
##
## Created by: Qt User Interface Compiler version 6.3.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QMetaObject, Qt)
from PySide6.QtWidgets import (QHBoxLayout, QLabel)

from widgets.IconLabel import IconLabel


class Ui_FileTemplate(object):
    def setupUi(self, FileTemplate):
        if not FileTemplate.objectName():
            FileTemplate.setObjectName(u"FileTemplate")
        FileTemplate.resize(440, 34)
        self.horizontalLayout = QHBoxLayout(FileTemplate)
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.nameWidget = IconLabel(FileTemplate)
        self.nameWidget.setObjectName(u"nameWidget")

        self.horizontalLayout.addWidget(self.nameWidget)

        self.sizeLabel = QLabel(FileTemplate)
        self.sizeLabel.setObjectName(u"sizeLabel")
        self.sizeLabel.setLayoutDirection(Qt.LeftToRight)
        self.sizeLabel.setAlignment(Qt.AlignRight | Qt.AlignTrailing | Qt.AlignVCenter)

        self.horizontalLayout.addWidget(self.sizeLabel)

        self.retranslateUi(FileTemplate)

        QMetaObject.connectSlotsByName(FileTemplate)
    # setupUi

    def retranslateUi(self, FileTemplate):
        FileTemplate.setWindowTitle(QCoreApplication.translate("FileTemplate", u"Form", None))
        self.sizeLabel.setText(QCoreApplication.translate("FileTemplate", u"size", None))
    # retranslateUi




from PySide6.QtWidgets import QWidget
from github import GithubException

from modules.repository import Repository
from ui.widgets import Ui_CreateRepo
from utils import message


class CreateRepository(QWidget):
    def __init__(self, user):
        """
        Module for creating a new repository in the user's account.

        Parameters
        ----------
        user: User
            The user who will create the repository.
        """
        super(CreateRepository, self).__init__()

        self.ui = Ui_CreateRepo()
        self.ui.setupUi(self)

        self.user = user

        self.new_repo = None

        self.config()
        self.fill()

    def fill(self):
        """
        Fill the combo boxes with the available templates.
        """
        ignores = [""]
        repo = self.user.github.get_repo("github/gitignore")
        for file in repo.get_contents(""):
            if file.type == "file":
                ignores.append(file.name.split(".")[0])
        self.ui.gitignoreTemplateComboBox.add_items(ignores)

        licenses = ["", "MIT", "ISC", "Apache-2.0", "BSD-2-Clause", "BSD-3-Clause", "GPL-2.0", "GPL-3.0", "LGPL-2.1",
                    "LGPL-3.0", "Unlicense", "AGPL-3.0"]

        self.ui.licenseTemplateComboBox.add_items(licenses)

    def config(self):
        """
        Configure the module.
        """
        self.ui.cancelButton.clicked.connect(self.close)
        self.ui.createRepoButton.clicked.connect(self.create_repo)
        self.ui.nameLineEdit.textChanged.connect(self.check_name)
        self.ui.warningLabel.setText("")
        self.ui.warningLabel.set_icon("fa.warning", "orange")
        self.ui.warningLabel.hide()

    def check_name(self, text):
        """
        Check if the name of the repository is valid.

        Parameters
        ----------
        text : str
            The name of the repository.
        """
        if " " in text:
            self.ui.warningLabel.setText("Your new repository will be created as " + text.replace(" ", "-") + ".")
            if self.ui.warningLabel.isHidden():
                self.ui.warningLabel.show()
        else:
            self.ui.warningLabel.hide()

    def create_repo(self):
        """
        Create a new repository.
        """
        if message('warning', 'Are you sure you want to create this repository?'):
            if self.ui.nameLineEdit.text() != '':
                try:
                    repo = self.user.get_data().create_repo(
                        name=self.ui.nameLineEdit.text(),
                        description=self.ui.descriptionLineEdit.text(),
                        homepage=self.ui.homepageLineEdit.text(),
                        private=self.ui.privateCheckBox.isChecked(),
                        has_issues=self.ui.hasIssuesCheckBox.isChecked(),
                        has_wiki=self.ui.hasWikiCheckBox.isChecked(),
                        has_downloads=self.ui.hasDownloadsCheckBox.isChecked(),
                        auto_init=self.ui.autoInitCheckBox.isChecked(),
                        allow_merge_commit=self.ui.allowMergeCommitCheckBox.isChecked(),
                        allow_rebase_merge=self.ui.allowRebaseMergeCheckBox.isChecked(),
                        license_template=self.ui.licenseTemplateComboBox.currentText(),
                        gitignore_template=self.ui.gitignoreTemplateComboBox.currentText())

                    self.new_repo = Repository(repo, self.user)
                    self.new_repo.show()

                    self.close()
                except GithubException as e:
                    message('error', e.data['message'])
            else:
                message('error', 'Repository name cannot be empty')



# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'overview.ui'
##
## Created by: Qt User Interface Compiler version 6.3.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QMetaObject)
from PySide6.QtGui import (QFont)
from PySide6.QtWidgets import (QGridLayout, QLabel, QLayout,
                               QSizePolicy, QVBoxLayout, QWidget)

class Ui_Overview(object):
    def setupUi(self, Overview):
        if not Overview.objectName():
            Overview.setObjectName(u"Overview")
        Overview.resize(827, 439)
        self.verticalLayout = QVBoxLayout(Overview)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.label = QLabel(Overview)
        self.label.setObjectName(u"label")
        sizePolicy = QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy)
        font = QFont()
        font.setPointSize(13)
        font.setBold(True)
        self.label.setFont(font)

        self.verticalLayout.addWidget(self.label)

        self.gridLayout = QGridLayout()
        self.gridLayout.setSpacing(2)
        self.gridLayout.setObjectName(u"gridLayout")
        self.gridLayout.setSizeConstraint(QLayout.SetDefaultConstraint)

        self.verticalLayout.addLayout(self.gridLayout)

        self.label_2 = QLabel(Overview)
        self.label_2.setObjectName(u"label_2")
        sizePolicy.setHeightForWidth(self.label_2.sizePolicy().hasHeightForWidth())
        self.label_2.setSizePolicy(sizePolicy)
        self.label_2.setFont(font)

        self.verticalLayout.addWidget(self.label_2)

        self.contributionsWidget = QWidget(Overview)
        self.contributionsWidget.setObjectName(u"contributionsWidget")

        self.verticalLayout.addWidget(self.contributionsWidget)

        self.retranslateUi(Overview)

        QMetaObject.connectSlotsByName(Overview)
    # setupUi

    def retranslateUi(self, Overview):
        Overview.setWindowTitle(QCoreApplication.translate("Overview", u"Form", None))
        self.label.setText(QCoreApplication.translate("Overview", u"Popular repositories", None))
        self.label_2.setText(QCoreApplication.translate("Overview", u"Last year contributions", None))
    # retranslateUi




# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'repository.ui'
##
## Created by: Qt User Interface Compiler version 6.3.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QMetaObject, Qt)
from PySide6.QtGui import (QFont)
from PySide6.QtWidgets import (QComboBox, QFrame, QHBoxLayout,
                               QLabel, QLayout, QListWidget, QPushButton, QSizePolicy, QSpacerItem, QTabWidget,
                               QVBoxLayout, QWidget)

from widgets.IconLabel import IconLabel


class Ui_repository(object):
    def setupUi(self, repository):
        if not repository.objectName():
            repository.setObjectName(u"repository")
        repository.resize(936, 640)
        self.verticalLayout = QVBoxLayout(repository)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.horizontalLayout_5 = QHBoxLayout()
        self.horizontalLayout_5.setObjectName(u"horizontalLayout_5")
        self.horizontalLayout_5.setContentsMargins(-1, -1, -1, 0)
        self.repoLabel = QLabel(repository)
        self.repoLabel.setObjectName(u"repoLabel")

        self.horizontalLayout_5.addWidget(self.repoLabel)

        self.watchButton = QPushButton(repository)
        self.watchButton.setObjectName(u"watchButton")
        sizePolicy = QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.watchButton.sizePolicy().hasHeightForWidth())
        self.watchButton.setSizePolicy(sizePolicy)

        self.horizontalLayout_5.addWidget(self.watchButton)

        self.forkButton = QPushButton(repository)
        self.forkButton.setObjectName(u"forkButton")
        sizePolicy.setHeightForWidth(self.forkButton.sizePolicy().hasHeightForWidth())
        self.forkButton.setSizePolicy(sizePolicy)

        self.horizontalLayout_5.addWidget(self.forkButton)

        self.starButton = QPushButton(repository)
        self.starButton.setObjectName(u"starButton")
        sizePolicy.setHeightForWidth(self.starButton.sizePolicy().hasHeightForWidth())
        self.starButton.setSizePolicy(sizePolicy)

        self.horizontalLayout_5.addWidget(self.starButton)


        self.verticalLayout.addLayout(self.horizontalLayout_5)

        self.tabWidget = QTabWidget(repository)
        self.tabWidget.setObjectName(u"tabWidget")
        self.code = QWidget()
        self.code.setObjectName(u"code")
        self.horizontalLayout = QHBoxLayout(self.code)
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.verticalLayout_2 = QVBoxLayout()
        self.verticalLayout_2.setObjectName(u"verticalLayout_2")
        self.horizontalLayout_3 = QHBoxLayout()
        self.horizontalLayout_3.setObjectName(u"horizontalLayout_3")
        self.branchComboBox = QComboBox(self.code)
        self.branchComboBox.setObjectName(u"branchComboBox")
        sizePolicy.setHeightForWidth(self.branchComboBox.sizePolicy().hasHeightForWidth())
        self.branchComboBox.setSizePolicy(sizePolicy)

        self.horizontalLayout_3.addWidget(self.branchComboBox)

        self.branchWidget = QWidget(self.code)
        self.branchWidget.setObjectName(u"branchWidget")
        sizePolicy.setHeightForWidth(self.branchWidget.sizePolicy().hasHeightForWidth())
        self.branchWidget.setSizePolicy(sizePolicy)

        self.horizontalLayout_3.addWidget(self.branchWidget)

        self.tagsWidget = QWidget(self.code)
        self.tagsWidget.setObjectName(u"tagsWidget")
        sizePolicy.setHeightForWidth(self.tagsWidget.sizePolicy().hasHeightForWidth())
        self.tagsWidget.setSizePolicy(sizePolicy)

        self.horizontalLayout_3.addWidget(self.tagsWidget)

        self.horizontalSpacer_2 = QSpacerItem(40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.horizontalLayout_3.addItem(self.horizontalSpacer_2)

        self.codeButton = QPushButton(self.code)
        self.codeButton.setObjectName(u"codeButton")
        sizePolicy.setHeightForWidth(self.codeButton.sizePolicy().hasHeightForWidth())
        self.codeButton.setSizePolicy(sizePolicy)

        self.horizontalLayout_3.addWidget(self.codeButton)


        self.verticalLayout_2.addLayout(self.horizontalLayout_3)

        self.frame = QFrame(self.code)
        self.frame.setObjectName(u"frame")
        self.frame.setFrameShape(QFrame.StyledPanel)
        self.frame.setFrameShadow(QFrame.Plain)
        self.horizontalLayout_4 = QHBoxLayout(self.frame)
        self.horizontalLayout_4.setObjectName(u"horizontalLayout_4")
        self.profileImageLabel = QLabel(self.frame)
        self.profileImageLabel.setObjectName(u"profileImageLabel")
        sizePolicy.setHeightForWidth(self.profileImageLabel.sizePolicy().hasHeightForWidth())
        self.profileImageLabel.setSizePolicy(sizePolicy)

        self.horizontalLayout_4.addWidget(self.profileImageLabel)

        self.usernameLabel = QLabel(self.frame)
        self.usernameLabel.setObjectName(u"usernameLabel")
        sizePolicy.setHeightForWidth(self.usernameLabel.sizePolicy().hasHeightForWidth())
        self.usernameLabel.setSizePolicy(sizePolicy)

        self.horizontalLayout_4.addWidget(self.usernameLabel)

        self.commitLabel = QLabel(self.frame)
        self.commitLabel.setObjectName(u"commitLabel")
        sizePolicy.setHeightForWidth(self.commitLabel.sizePolicy().hasHeightForWidth())
        self.commitLabel.setSizePolicy(sizePolicy)

        self.horizontalLayout_4.addWidget(self.commitLabel)

        self.horizontalSpacer_3 = QSpacerItem(40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.horizontalLayout_4.addItem(self.horizontalSpacer_3)

        self.numsLabel = QLabel(self.frame)
        self.numsLabel.setObjectName(u"numsLabel")
        sizePolicy.setHeightForWidth(self.numsLabel.sizePolicy().hasHeightForWidth())
        self.numsLabel.setSizePolicy(sizePolicy)

        self.horizontalLayout_4.addWidget(self.numsLabel)

        self.timeLabel = QLabel(self.frame)
        self.timeLabel.setObjectName(u"timeLabel")
        sizePolicy.setHeightForWidth(self.timeLabel.sizePolicy().hasHeightForWidth())
        self.timeLabel.setSizePolicy(sizePolicy)

        self.horizontalLayout_4.addWidget(self.timeLabel)

        self.commitsWidget = IconLabel(self.frame)
        self.commitsWidget.setObjectName(u"commitsWidget")
        sizePolicy.setHeightForWidth(self.commitsWidget.sizePolicy().hasHeightForWidth())
        self.commitsWidget.setSizePolicy(sizePolicy)

        self.horizontalLayout_4.addWidget(self.commitsWidget)


        self.verticalLayout_2.addWidget(self.frame)

        self.filesListWidget = QListWidget(self.code)
        self.filesListWidget.setObjectName(u"filesListWidget")

        self.verticalLayout_2.addWidget(self.filesListWidget)


        self.horizontalLayout.addLayout(self.verticalLayout_2)

        self.verticalLayout_3 = QVBoxLayout()
        self.verticalLayout_3.setObjectName(u"verticalLayout_3")
        self.verticalLayout_3.setSizeConstraint(QLayout.SetFixedSize)
        self.verticalLayout_3.setContentsMargins(-1, -1, -1, 0)
        self.horizontalLayout_2 = QHBoxLayout()
        self.horizontalLayout_2.setObjectName(u"horizontalLayout_2")
        self.horizontalLayout_2.setSizeConstraint(QLayout.SetFixedSize)
        self.label = QLabel(self.code)
        self.label.setObjectName(u"label")
        sizePolicy.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy)
        font = QFont()
        font.setBold(True)
        self.label.setFont(font)

        self.horizontalLayout_2.addWidget(self.label)

        self.configButton = QPushButton(self.code)
        self.configButton.setObjectName(u"configButton")
        sizePolicy.setHeightForWidth(self.configButton.sizePolicy().hasHeightForWidth())
        self.configButton.setSizePolicy(sizePolicy)
        self.configButton.setLayoutDirection(Qt.RightToLeft)

        self.horizontalLayout_2.addWidget(self.configButton)

        self.verticalLayout_3.addLayout(self.horizontalLayout_2)

        self.descLabel = QLabel(self.code)
        self.descLabel.setObjectName(u"descLabel")
        sizePolicy.setHeightForWidth(self.descLabel.sizePolicy().hasHeightForWidth())
        self.descLabel.setSizePolicy(sizePolicy)

        self.verticalLayout_3.addWidget(self.descLabel)

        self.licenseWidget = IconLabel(self.code)
        self.licenseWidget.setObjectName(u"licenseWidget")
        sizePolicy.setHeightForWidth(self.licenseWidget.sizePolicy().hasHeightForWidth())
        self.licenseWidget.setSizePolicy(sizePolicy)

        self.verticalLayout_3.addWidget(self.licenseWidget)

        self.starWidget = IconLabel(self.code)
        self.starWidget.setObjectName(u"starWidget")
        sizePolicy.setHeightForWidth(self.starWidget.sizePolicy().hasHeightForWidth())
        self.starWidget.setSizePolicy(sizePolicy)

        self.verticalLayout_3.addWidget(self.starWidget)

        self.watchingWidget = IconLabel(self.code)
        self.watchingWidget.setObjectName(u"watchingWidget")
        sizePolicy.setHeightForWidth(self.watchingWidget.sizePolicy().hasHeightForWidth())
        self.watchingWidget.setSizePolicy(sizePolicy)

        self.verticalLayout_3.addWidget(self.watchingWidget)

        self.forksWidget = IconLabel(self.code)
        self.forksWidget.setObjectName(u"forksWidget")
        sizePolicy.setHeightForWidth(self.forksWidget.sizePolicy().hasHeightForWidth())
        self.forksWidget.setSizePolicy(sizePolicy)

        self.verticalLayout_3.addWidget(self.forksWidget)

        self.line = QFrame(self.code)
        self.line.setObjectName(u"line")
        self.line.setFrameShape(QFrame.HLine)
        self.line.setFrameShadow(QFrame.Sunken)

        self.verticalLayout_3.addWidget(self.line)

        self.label_2 = QLabel(self.code)
        self.label_2.setObjectName(u"label_2")
        sizePolicy.setHeightForWidth(self.label_2.sizePolicy().hasHeightForWidth())
        self.label_2.setSizePolicy(sizePolicy)
        self.label_2.setFont(font)

        self.verticalLayout_3.addWidget(self.label_2)

        self.releasesWidget = IconLabel(self.code)
        self.releasesWidget.setObjectName(u"releasesWidget")
        sizePolicy.setHeightForWidth(self.releasesWidget.sizePolicy().hasHeightForWidth())
        self.releasesWidget.setSizePolicy(sizePolicy)

        self.verticalLayout_3.addWidget(self.releasesWidget)

        self.verticalSpacer = QSpacerItem(20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding)

        self.verticalLayout_3.addItem(self.verticalSpacer)

        self.horizontalLayout.addLayout(self.verticalLayout_3)

        self.tabWidget.addTab(self.code, "")
        self.issues = QWidget()
        self.issues.setObjectName(u"issues")
        self.verticalLayout_4 = QVBoxLayout(self.issues)
        self.verticalLayout_4.setObjectName(u"verticalLayout_4")
        self.issuesListWidget = QListWidget(self.issues)
        self.issuesListWidget.setObjectName(u"issuesListWidget")

        self.verticalLayout_4.addWidget(self.issuesListWidget)

        self.tabWidget.addTab(self.issues, "")

        self.verticalLayout.addWidget(self.tabWidget)

        self.retranslateUi(repository)

        self.tabWidget.setCurrentIndex(0)

        QMetaObject.connectSlotsByName(repository)
    # setupUi

    def retranslateUi(self, repository):
        repository.setWindowTitle(QCoreApplication.translate("repository", u"Form", None))
        self.repoLabel.setText(QCoreApplication.translate("repository", u"repo", None))
        self.watchButton.setText(QCoreApplication.translate("repository", u"Watch", None))
        self.forkButton.setText(QCoreApplication.translate("repository", u"Fork", None))
        self.starButton.setText(QCoreApplication.translate("repository", u"Star", None))
        self.codeButton.setText(QCoreApplication.translate("repository", u"Code", None))
        self.profileImageLabel.setText(QCoreApplication.translate("repository", u"img", None))
        self.usernameLabel.setText(QCoreApplication.translate("repository", u"username", None))
        self.commitLabel.setText(QCoreApplication.translate("repository", u"commit desc", None))
        self.numsLabel.setText(QCoreApplication.translate("repository", u"nums", None))
        self.timeLabel.setText(QCoreApplication.translate("repository", u"1 day ago", None))
        self.label.setText(QCoreApplication.translate("repository", u"About", None))
        self.configButton.setText("")
        self.descLabel.setText(QCoreApplication.translate("repository", u"desc", None))
        self.label_2.setText(QCoreApplication.translate("repository", u"Releases", None))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.code),
                                  QCoreApplication.translate("repository", u"Code", None))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.issues),
                                  QCoreApplication.translate("repository", u"Issues", None))
    # retranslateUi




# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'repositories.ui'
##
## Created by: Qt User Interface Compiler version 6.3.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QMetaObject)
from PySide6.QtGui import (QFont)
from PySide6.QtWidgets import (QHBoxLayout, QLineEdit, QListWidget,
                               QPushButton, QSizePolicy, QVBoxLayout)


class Ui_Repositories(object):
    def setupUi(self, Repositories):
        if not Repositories.objectName():
            Repositories.setObjectName(u"Repositories")
        Repositories.resize(556, 357)
        self.verticalLayout = QVBoxLayout(Repositories)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.horizontalLayout = QHBoxLayout()
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.horizontalLayout.setContentsMargins(-1, -1, -1, 0)
        self.lineEdit = QLineEdit(Repositories)
        self.lineEdit.setObjectName(u"lineEdit")

        self.horizontalLayout.addWidget(self.lineEdit)

        self.newButton = QPushButton(Repositories)
        self.newButton.setObjectName(u"newButton")
        sizePolicy = QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.newButton.sizePolicy().hasHeightForWidth())
        self.newButton.setSizePolicy(sizePolicy)
        font = QFont()
        font.setBold(True)
        self.newButton.setFont(font)

        self.horizontalLayout.addWidget(self.newButton)

        self.verticalLayout.addLayout(self.horizontalLayout)

        self.listWidget = QListWidget(Repositories)
        self.listWidget.setObjectName(u"listWidget")

        self.verticalLayout.addWidget(self.listWidget)

        self.retranslateUi(Repositories)

        QMetaObject.connectSlotsByName(Repositories)
    # setupUi

    def retranslateUi(self, Repositories):
        Repositories.setWindowTitle(QCoreApplication.translate("Repositories", u"Form", None))
        self.lineEdit.setPlaceholderText(QCoreApplication.translate("Repositories", u"Find a repository...", None))
        self.newButton.setText(QCoreApplication.translate("Repositories", u"New", None))
    # retranslateUi




import os
from pathlib import Path

USER_HOME_PATH = Path.home()
PROJECT_FOLDER = os.path.dirname(os.path.dirname(__file__))
RESOURCES_FOLDER = os.path.join(PROJECT_FOLDER, 'resources')
ICONS_FOLDER = os.path.join(RESOURCES_FOLDER, 'icons')


def get_icon(icon_name):
    """
    Returns the path of an icon

    Parameters
    ----------
    icon_name : str
        Name of the icon

    Returns
    -------
    str
        Path of the icon

    Examples
    --------
    >>> get_icon('icon.png')
    '/home/user/Documents/Projects/project/resources/icons/icon.png'
    """
    icon = os.path.join(ICONS_FOLDER, icon_name)
    if not file_exists(icon):
        icon = False

    return icon


def file_exists(file):
    """
    Checks if a file exists

    Returns
    -------
    bool
        True if the file exists, False otherwise

    Examples
    --------
    >>> file_exists('/home/user/Documents/Projects/project/resources/icons/icon.png')
    True
    >>> file_exists('/home/user/Documents/Projects/project/resources/icons/icon.png.png')
    False
    """
    return os.path.exists(file)


LOGO = get_icon("GitHub_Manager.png")



# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'local_repository_template.ui'
##
## Created by: Qt User Interface Compiler version 6.3.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QMetaObject)
from PySide6.QtWidgets import (QHBoxLayout, QLabel, QLineEdit,
                               QPushButton, QSizePolicy, QSpacerItem, QVBoxLayout)


class Ui_LocalRepositoryTemplate(object):
    def setupUi(self, LocalRepositoryTemplate):
        if not LocalRepositoryTemplate.objectName():
            LocalRepositoryTemplate.setObjectName(u"LocalRepositoryTemplate")
        LocalRepositoryTemplate.resize(554, 85)
        self.verticalLayout_2 = QVBoxLayout(LocalRepositoryTemplate)
        self.verticalLayout_2.setObjectName(u"verticalLayout_2")
        self.horizontalLayout = QHBoxLayout()
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.repoNameLabel = QLabel(LocalRepositoryTemplate)
        self.repoNameLabel.setObjectName(u"repoNameLabel")

        self.horizontalLayout.addWidget(self.repoNameLabel)

        self.horizontalSpacer = QSpacerItem(40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.horizontalLayout.addItem(self.horizontalSpacer)

        self.githubButton = QPushButton(LocalRepositoryTemplate)
        self.githubButton.setObjectName(u"githubButton")
        sizePolicy = QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.githubButton.sizePolicy().hasHeightForWidth())
        self.githubButton.setSizePolicy(sizePolicy)

        self.horizontalLayout.addWidget(self.githubButton)

        self.verticalLayout_2.addLayout(self.horizontalLayout)

        self.horizontalLayout_2 = QHBoxLayout()
        self.horizontalLayout_2.setObjectName(u"horizontalLayout_2")
        self.label = QLabel(LocalRepositoryTemplate)
        self.label.setObjectName(u"label")

        self.horizontalLayout_2.addWidget(self.label)

        self.pathLineEdit = QLineEdit(LocalRepositoryTemplate)
        self.pathLineEdit.setObjectName(u"pathLineEdit")

        self.horizontalLayout_2.addWidget(self.pathLineEdit)

        self.verticalLayout_2.addLayout(self.horizontalLayout_2)

        self.retranslateUi(LocalRepositoryTemplate)

        QMetaObject.connectSlotsByName(LocalRepositoryTemplate)

    # setupUi

    def retranslateUi(self, LocalRepositoryTemplate):
        LocalRepositoryTemplate.setWindowTitle(QCoreApplication.translate("LocalRepositoryTemplate", u"Form", None))
        self.repoNameLabel.setText(QCoreApplication.translate("LocalRepositoryTemplate", u"repo-name", None))
        self.githubButton.setText("")
        self.label.setText(QCoreApplication.translate("LocalRepositoryTemplate", u"Path:", None))
    # retranslateUi



from PySide6.QtWidgets import QWidget
from github.ContentFile import ContentFile

from ui.widgets import Ui_FileTemplate
from utils import format_file_size


class FileTemplate(QWidget):
    def __init__(self, name, content_type, size):
        """
        Initialize the widget

        Parameters
        ----------
        name : str
            The name of the file
        content_type : str
            The content type of the file
        size : int
            The size of the file
        """
        super(FileTemplate, self).__init__()
        self.ui = Ui_FileTemplate()
        self.ui.setupUi(self)

        self.name = name
        self.content_type = content_type
        self.size = size

        self.fill()

    def fill(self):
        """
        Fill the widget with the data from the content file
        """
        self.ui.nameWidget.setText(self.name)
        self.ui.nameWidget.set_icon("fa5s.file-alt" if self.content_type == "file" else "fa5s.folder")
        self.ui.sizeLabel.setText(str(format_file_size(self.size, "B", "KB")) + " KB")
        if self.content_type == "dir":
            self.ui.sizeLabel.setText("")



import os
import shutil
from datetime import datetime

import requests
from PySide6.QtCore import QUrl
from PySide6.QtGui import QDesktopServices
from PySide6.QtWidgets import QWidget, QVBoxLayout, QFileSystemModel
from github.Repository import Repository

from ui.widgets import Ui_localRepository
from utils import get_repo_info, time_formatter, delete_repository_dialog, message
from widgets import MplCanvas


class LocalRepository(QWidget):
    def __init__(self, repo_path, user):
        """
        Window to show information about a local repository

        Parameters
        ----------
        repo_path : str
            Path to the repository folder
        user : User
            User object
        """
        super(LocalRepository, self).__init__()
        self.ui = Ui_localRepository()
        self.ui.setupUi(self)

        self.repo_path = repo_path
        self.user = user
        self.url = None
        self.model = None

        self.owner, self.repo_name, self.full_repo_name = get_repo_info(self.repo_path)

        self.config()
        self.load_data()
        self.load_files()

    def load_data(self):
        """
        Loads the data from the api and loads it in the UI

        Raises
        ------
        Exception
            If the repo is not found in the user's repositories, it disables some UI elements
        """
        try:
            self.setWindowTitle(f'{self.repo_name} - {self.owner}')
            repo: Repository = self.user.github.get_repo(self.full_repo_name)
            self.ui.repoLabel.setText(repo.name.upper())
            self.ui.fullNameLineEdit.setText(repo.full_name)
            self.ui.ownerLineEdit.setText(repo.owner.login)
            self.ui.descriptionLineEdit.setText(repo.description)
            self.ui.createdAtLineEdit.setText(repo.created_at.strftime("%d/%m/%Y"))
            self.ui.updatedLineEdit.setText(time_formatter("", time2=repo.updated_at))
            self.ui.languageLineEdit.setText(repo.language)
            self.ui.forksLineEdit.setText(str(repo.forks_count))
            self.ui.starsLineEdit.setText(str(repo.stargazers_count))
            self.ui.subscribersLineEdit.setText(str(repo.subscribers_count))
            self.url = repo.html_url
            self.plot()
        except Exception:
            self.setWindowTitle(f'{self.repo_name}')
            self.ui.repoLabel.setText(self.repo_name.upper())
            self.ui.fullNameLineEdit.setText(self.full_repo_name)
            self.ui.ownerLineEdit.setText(self.owner)
            self.ui.descriptionLabel.hide()
            self.ui.descriptionLineEdit.hide()
            self.ui.createdAtLabel.hide()
            self.ui.createdAtLineEdit.hide()
            self.ui.updatedLabel.hide()
            self.ui.updatedLineEdit.hide()
            self.ui.languageLabel.hide()
            self.ui.languageLineEdit.hide()
            self.ui.forksLabel.hide()
            self.ui.forksLineEdit.hide()
            self.ui.starsLabel.hide()
            self.ui.starsLineEdit.hide()
            self.ui.subscribersLabel.hide()
            self.ui.subscribersLineEdit.hide()
            self.ui.tabWidget.removeTab(2)
            self.ui.openBrowserButton.hide()
            self.ui.commitsImageWidget.hide()

    def plot(self):
        """
        Plots the commits graph in the commits tab of the UI
        """
        response = requests.get(f'https://api.github.com/repos/{self.full_repo_name}/stats/commit_activity',
                                auth=(self.user.get_data().login, self.user.token))
        weeks = []
        total = []
        if response.status_code == 200:
            for x in response.json():
                weeks.append(datetime.fromtimestamp(x["week"]).strftime('%d/%m'))
                total.append(x["total"])
            weeks = weeks[36:]
            total = total[36:]
            canvas = MplCanvas(width=10, height=6, dpi=75, xlabel='weeks', ylabel='total commits',
                               title='Commits per week')
            canvas.ax.bar(weeks, total)
            self.ui.commitsImageWidget.setLayout(QVBoxLayout(self.ui.commitsImageWidget).addWidget(canvas))

    def load_files(self):
        """
        Loads the files of the repository in the files tab of the UI
        """
        self.model = QFileSystemModel()
        self.model.setRootPath(self.repo_path)
        self.ui.treeView.setModel(self.model)
        self.ui.treeView.setRootIndex(self.model.index(self.repo_path))
        self.ui.treeView.setSortingEnabled(True)

    def config(self):
        """
        Configures the UI
        """
        self.ui.deleteButton.clicked.connect(self.delete_repo)
        self.ui.openFolderButton.clicked.connect(self.open_folder)
        self.ui.openBrowserButton.clicked.connect(self.open_browser)

    def delete_repo(self):
        """
        Deletes the repo folder and all its contents

        Raises
        ------
        Exception
            If the repo folder cannot be deleted and shows an error message
        """
        if delete_repository_dialog('local'):
            try:
                shutil.rmtree(self.repo_path, ignore_errors=True)
                self.close()
            except Exception as e:
                message('error', e)

    def open_folder(self):
        """
        Opens the folder of the repo
        """
        os.startfile(self.repo_path)

    def open_browser(self):
        """
        Open the GitHub page of the repo
        """
        QDesktopServices.openUrl(QUrl(self.url))



# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'aboutwindow.ui'
##
## Created by: Qt User Interface Compiler version 6.3.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QMetaObject, Qt)
from PySide6.QtGui import (QAction, QFont)
from PySide6.QtWidgets import (QHBoxLayout, QLabel, QLayout,
                               QSizePolicy, QStatusBar, QVBoxLayout,
                               QWidget)

from widgets.HyperlinkLabel import HyperlinkLabel


class Ui_GitHubManagerAbout(object):
    def setupUi(self, GitHubManagerAbout):
        if not GitHubManagerAbout.objectName():
            GitHubManagerAbout.setObjectName(u"GitHubManagerAbout")
        GitHubManagerAbout.setEnabled(True)
        GitHubManagerAbout.resize(432, 192)
        sizePolicy = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(GitHubManagerAbout.sizePolicy().hasHeightForWidth())
        GitHubManagerAbout.setSizePolicy(sizePolicy)
        GitHubManagerAbout.setToolButtonStyle(Qt.ToolButtonIconOnly)
        self.actionAbout = QAction(GitHubManagerAbout)
        self.actionAbout.setObjectName(u"actionAbout")
        self.actionHow_to_get_an_GitHub_acces_token = QAction(GitHubManagerAbout)
        self.actionHow_to_get_an_GitHub_acces_token.setObjectName(u"actionHow_to_get_an_GitHub_acces_token")
        self.actionExit = QAction(GitHubManagerAbout)
        self.actionExit.setObjectName(u"actionExit")
        self.centralwidget = QWidget(GitHubManagerAbout)
        self.centralwidget.setObjectName(u"centralwidget")
        self.verticalLayout_2 = QVBoxLayout(self.centralwidget)
        self.verticalLayout_2.setObjectName(u"verticalLayout_2")
        self.signInLabel = QLabel(self.centralwidget)
        self.signInLabel.setObjectName(u"signInLabel")
        sizePolicy1 = QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
        sizePolicy1.setHorizontalStretch(0)
        sizePolicy1.setVerticalStretch(0)
        sizePolicy1.setHeightForWidth(self.signInLabel.sizePolicy().hasHeightForWidth())
        self.signInLabel.setSizePolicy(sizePolicy1)
        font = QFont()
        font.setPointSize(15)
        font.setBold(True)
        self.signInLabel.setFont(font)
        self.signInLabel.setLayoutDirection(Qt.LeftToRight)
        self.signInLabel.setAlignment(Qt.AlignCenter)

        self.verticalLayout_2.addWidget(self.signInLabel)

        self.horizontalLayout = QHBoxLayout()
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.ghmImageLabel = QLabel(self.centralwidget)
        self.ghmImageLabel.setObjectName(u"ghmImageLabel")
        sizePolicy2 = QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Preferred)
        sizePolicy2.setHorizontalStretch(0)
        sizePolicy2.setVerticalStretch(0)
        sizePolicy2.setHeightForWidth(self.ghmImageLabel.sizePolicy().hasHeightForWidth())
        self.ghmImageLabel.setSizePolicy(sizePolicy2)
        self.ghmImageLabel.setAlignment(Qt.AlignCenter)

        self.horizontalLayout.addWidget(self.ghmImageLabel)

        self.verticalLayout = QVBoxLayout()
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.horizontalLayout_2 = QHBoxLayout()
        self.horizontalLayout_2.setObjectName(u"horizontalLayout_2")
        self.horizontalLayout_2.setSizeConstraint(QLayout.SetDefaultConstraint)
        self.label = QLabel(self.centralwidget)
        self.label.setObjectName(u"label")
        sizePolicy3 = QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
        sizePolicy3.setHorizontalStretch(0)
        sizePolicy3.setVerticalStretch(0)
        sizePolicy3.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy3)
        font1 = QFont()
        font1.setBold(True)
        self.label.setFont(font1)

        self.horizontalLayout_2.addWidget(self.label)

        self.versionLabel = QLabel(self.centralwidget)
        self.versionLabel.setObjectName(u"versionLabel")
        sizePolicy1.setHeightForWidth(self.versionLabel.sizePolicy().hasHeightForWidth())
        self.versionLabel.setSizePolicy(sizePolicy1)

        self.horizontalLayout_2.addWidget(self.versionLabel)

        self.verticalLayout.addLayout(self.horizontalLayout_2)

        self.horizontalLayout_3 = QHBoxLayout()
        self.horizontalLayout_3.setObjectName(u"horizontalLayout_3")
        self.label_2 = QLabel(self.centralwidget)
        self.label_2.setObjectName(u"label_2")
        sizePolicy3.setHeightForWidth(self.label_2.sizePolicy().hasHeightForWidth())
        self.label_2.setSizePolicy(sizePolicy3)
        self.label_2.setFont(font1)

        self.horizontalLayout_3.addWidget(self.label_2)

        self.gitHubLabel = HyperlinkLabel(self.centralwidget)
        self.gitHubLabel.setObjectName(u"gitHubLabel")
        sizePolicy1.setHeightForWidth(self.gitHubLabel.sizePolicy().hasHeightForWidth())
        self.gitHubLabel.setSizePolicy(sizePolicy1)

        self.horizontalLayout_3.addWidget(self.gitHubLabel)

        self.verticalLayout.addLayout(self.horizontalLayout_3)

        self.horizontalLayout_4 = QHBoxLayout()
        self.horizontalLayout_4.setObjectName(u"horizontalLayout_4")
        self.label_4 = QLabel(self.centralwidget)
        self.label_4.setObjectName(u"label_4")
        sizePolicy3.setHeightForWidth(self.label_4.sizePolicy().hasHeightForWidth())
        self.label_4.setSizePolicy(sizePolicy3)
        self.label_4.setFont(font1)

        self.horizontalLayout_4.addWidget(self.label_4)

        self.issueTrackerLabel = HyperlinkLabel(self.centralwidget)
        self.issueTrackerLabel.setObjectName(u"issueTrackerLabel")
        sizePolicy1.setHeightForWidth(self.issueTrackerLabel.sizePolicy().hasHeightForWidth())
        self.issueTrackerLabel.setSizePolicy(sizePolicy1)

        self.horizontalLayout_4.addWidget(self.issueTrackerLabel)

        self.verticalLayout.addLayout(self.horizontalLayout_4)

        self.horizontalLayout_5 = QHBoxLayout()
        self.horizontalLayout_5.setObjectName(u"horizontalLayout_5")
        self.label_6 = QLabel(self.centralwidget)
        self.label_6.setObjectName(u"label_6")
        sizePolicy3.setHeightForWidth(self.label_6.sizePolicy().hasHeightForWidth())
        self.label_6.setSizePolicy(sizePolicy3)
        self.label_6.setFont(font1)

        self.horizontalLayout_5.addWidget(self.label_6)

        self.verticalLayout_3 = QVBoxLayout()
        self.verticalLayout_3.setObjectName(u"verticalLayout_3")
        self.horizontalLayout_6 = QHBoxLayout()
        self.horizontalLayout_6.setObjectName(u"horizontalLayout_6")
        self.label_7 = QLabel(self.centralwidget)
        self.label_7.setObjectName(u"label_7")
        sizePolicy3.setHeightForWidth(self.label_7.sizePolicy().hasHeightForWidth())
        self.label_7.setSizePolicy(sizePolicy3)

        self.horizontalLayout_6.addWidget(self.label_7)

        self.icons8Label = HyperlinkLabel(self.centralwidget)
        self.icons8Label.setObjectName(u"icons8Label")
        sizePolicy1.setHeightForWidth(self.icons8Label.sizePolicy().hasHeightForWidth())
        self.icons8Label.setSizePolicy(sizePolicy1)

        self.horizontalLayout_6.addWidget(self.icons8Label)

        self.verticalLayout_3.addLayout(self.horizontalLayout_6)

        self.horizontalLayout_5.addLayout(self.verticalLayout_3)

        self.verticalLayout.addLayout(self.horizontalLayout_5)

        self.horizontalLayout.addLayout(self.verticalLayout)

        self.verticalLayout_2.addLayout(self.horizontalLayout)

        GitHubManagerAbout.setCentralWidget(self.centralwidget)
        self.statusbar = QStatusBar(GitHubManagerAbout)
        self.statusbar.setObjectName(u"statusbar")
        GitHubManagerAbout.setStatusBar(self.statusbar)

        self.retranslateUi(GitHubManagerAbout)

        QMetaObject.connectSlotsByName(GitHubManagerAbout)

    # setupUi

    def retranslateUi(self, GitHubManagerAbout):
        GitHubManagerAbout.setWindowTitle(QCoreApplication.translate("GitHubManagerAbout", u"About", None))
        self.actionAbout.setText(QCoreApplication.translate("GitHubManagerAbout", u"About", None))
        self.actionHow_to_get_an_GitHub_acces_token.setText(
            QCoreApplication.translate("GitHubManagerAbout", u"How to get an GitHub acces token", None))
        self.actionExit.setText(QCoreApplication.translate("GitHubManagerAbout", u"Exit", None))
        self.signInLabel.setText(QCoreApplication.translate("GitHubManagerAbout", u"About GitHub Manager", None))
        self.ghmImageLabel.setText("")
        self.label.setText(QCoreApplication.translate("GitHubManagerAbout", u"Version:", None))
        self.versionLabel.setText(QCoreApplication.translate("GitHubManagerAbout", u"0.0", None))
        self.label_2.setText(QCoreApplication.translate("GitHubManagerAbout", u"GitHub:", None))
        self.gitHubLabel.setText(
            QCoreApplication.translate("GitHubManagerAbout", u"https://github.com/DomiTP/GitHub-Manager", None))
        self.label_4.setText(QCoreApplication.translate("GitHubManagerAbout", u"GitHub Issue Tracker:", None))
        self.issueTrackerLabel.setText(
            QCoreApplication.translate("GitHubManagerAbout", u"https://github.com/DomiTP/GitHub-Manager/issues", None))
        self.label_6.setText(QCoreApplication.translate("GitHubManagerAbout", u"Resources:", None))
        self.label_7.setText(QCoreApplication.translate("GitHubManagerAbout", u"Icons by icons8:", None))
        self.icons8Label.setText(QCoreApplication.translate("GitHubManagerAbout", u"https://icons8.com", None))
    # retranslateUi



from PySide6.QtCore import Qt
from PySide6.QtWidgets import QCompleter, QComboBox


def completion(word_list, widget, i=True):
    """
    Autocompletion of sender and subject

    Parameters
    ----------
    word_list : list
        List of words to be autocompleted
    widget : QComboBox
        Widget to be autocompleted
    i : bool
        If True, the autocompletion is case insensitive
    """
    word_set = set(word_list)
    completer = QCompleter(word_set)
    if i:
        completer.setCaseSensitivity(Qt.CaseInsensitive)
    else:
        completer.setCaseSensitivity(Qt.CaseSensitive)
    widget.setCompleter(completer)


class Autocomplete(QComboBox):
    def __init__(self, i=False, allow_duplicates=True):
        """
        Autocomplete ComboBox

        Parameters
        ----------
        i : bool
            If True, the autocompletion is case-insensitive
        allow_duplicates : bool
            If True, duplicates are allowed
        """
        super(Autocomplete, self).__init__()
        self.insensitivity = i
        self.allowDuplicates = allow_duplicates
        self.init()

    def init(self):
        """
        Configure the ComboBox
        """
        self.setEditable(True)
        self.setDuplicatesEnabled(self.allowDuplicates)

    def set_autocompletion(self, items, i):
        """
        Set autocompletion for the ComboBox
        Parameters
        ----------
        items : list
            List of items to be autocompleted
        i : bool
            If True, the autocompletion is case-insensitive
        """
        completion(items, self, i)

    def remove_item(self, item):
        """
        Remove an item from the ComboBox

        Parameters
        ----------
        item : int
            Index of the item to be removed
        """
        self.removeItem(item)

    def clear_items(self):
        """
        Clear all items from the ComboBox
        """
        self.clear()

    def add_items(self, items):
        """
        Add items to the ComboBox

        Parameters
        ----------
        items
            List of items to be added
        """
        self.addItems(items)
        self.set_autocompletion(items, i=self.insensitivity)
